==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp7394_001/MP7394_AddWorkOrderEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp7394_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderequipment_001.WorkOrderEquipment;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001}WorkOrderEquipment" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderEquipment" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="autoDelCalibration" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *       &lt;attribute name="isTraceRoute" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderEquipment"
})
@XmlRootElement(name = "MP7394_AddWorkOrderEquipment_001")
public class MP7394_AddWorkOrderEquipment_001 {

    @XmlElement(name = "WorkOrderEquipment", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001", required = true)
    protected List<WorkOrderEquipment> workOrderEquipment;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "autoDelCalibration")
    protected String autoDelCalibration;
    @XmlAttribute(name = "isTraceRoute")
    protected String isTraceRoute;

    /**
     * Gets the value of the workOrderEquipment property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the workOrderEquipment property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getWorkOrderEquipment().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link WorkOrderEquipment }
     * 
     * 
     */
    public List<WorkOrderEquipment> getWorkOrderEquipment() {
        if (workOrderEquipment == null) {
            workOrderEquipment = new ArrayList<WorkOrderEquipment>();
        }
        return this.workOrderEquipment;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété autoDelCalibration.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAutoDelCalibration() {
        if (autoDelCalibration == null) {
            return "true";
        } else {
            return autoDelCalibration;
        }
    }

    /**
     * Définit la valeur de la propriété autoDelCalibration.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAutoDelCalibration(String value) {
        this.autoDelCalibration = value;
    }

    /**
     * Obtient la valeur de la propriété isTraceRoute.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsTraceRoute() {
        if (isTraceRoute == null) {
            return "false";
        } else {
            return isTraceRoute;
        }
    }

    /**
     * Définit la valeur de la propriété isTraceRoute.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsTraceRoute(String value) {
        this.isTraceRoute = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_functions/mp7394_001/MP7394_AddWorkOrderEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp7394_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderequipment_001.WorkOrderEquipment;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001}WorkOrderEquipment" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderEquipment" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="autoDelCalibration" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *       &lt;attribute name="isTraceRoute" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderEquipment"
})
@XmlRootElement(name = "MP7394_AddWorkOrderEquipment_001")
public class MP7394_AddWorkOrderEquipment_001 {

    @XmlElement(name = "WorkOrderEquipment", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001", required = true)
    protected List<WorkOrderEquipment> workOrderEquipment;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "autoDelCalibration")
    protected String autoDelCalibration;
    @XmlAttribute(name = "isTraceRoute")
    protected String isTraceRoute;

    /**
     * Gets the value of the workOrderEquipment property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the workOrderEquipment property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getWorkOrderEquipment().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link WorkOrderEquipment }
     * 
     * 
     */
    public List<WorkOrderEquipment> getWorkOrderEquipment() {
        if (workOrderEquipment == null) {
            workOrderEquipment = new ArrayList<WorkOrderEquipment>();
        }
        return this.workOrderEquipment;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the autoDelCalibration property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAutoDelCalibration() {
        if (autoDelCalibration == null) {
            return "true";
        } else {
            return autoDelCalibration;
        }
    }

    /**
     * Sets the value of the autoDelCalibration property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAutoDelCalibration(String value) {
        this.autoDelCalibration = value;
    }

    /**
     * Gets the value of the isTraceRoute property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsTraceRoute() {
        if (isTraceRoute == null) {
            return "false";
        } else {
            return isTraceRoute;
        }
    }

    /**
     * Sets the value of the isTraceRoute property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsTraceRoute(String value) {
        this.isTraceRoute = value;
    }

}
